@@ -285,6 +285,8 @@ selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
   
   if (is_extended_selection_table(X) & !is.null(by.song)) attributes(X)$by.song  <- list(by.song = TRUE, song.column = by.song) else attributes(X)$by.song  <- list(by.song = FALSE, song.column = by.song)
   
+  attributes(X)$warbleR.version <- packageVersion("warbleR")
+  
   if (extended & confirm.extended & !is_extended_selection_table(X)) cat("'extended_selection_table' was not created")
   
   return(X)
@@ -498,11 +500,24 @@ print.extended_selection_table <- function(x, ...) {
   
   if (length(attr(x, "wave.objects")) > 6) cat(paste0("... and ", length(attr(x, "wave.objects")) - 6, " more \n"))  
   
-  cat("and a data frame (check.results) generated by checkres() (as attribute) \n")
+  cat("and a data frame (check.results) generated by check_sels() (as attribute) \n")
   
-  if (attr(x, "by.song")[[1]]) cat("the selection table was created by song (see 'class_extended_selection_table')") else
-    cat("the selection table was created by element (see 'class_extended_selection_table')")
-}
+  if (attr(x, "by.song")[[1]]) cat("the selection table was created by song (see 'class_extended_selection_table') \n") else
+    cat("the selection table was created by element (see 'class_extended_selection_table') \n")
+
+  # print number of sampling rates
+  smp.rts <- unique(attr(x, "check.results")$sample.rate)
+  cat(paste0(length(smp.rts), " sampling rate(s): ", paste(smp.rts, collapse = "/"), " \n"))
+
+  # print number of sampling rates
+  bt.dps <- unique(attr(x, "check.results")$bits)
+  cat(paste0(length(bt.dps), " bit depth(s): ", paste(bt.dps, collapse = "/"), " \n"))
+  
+  # print warbleR version
+  if (!is.null(attr(x, "warbleR.version")))
+    cat(paste0("created by warbleR ", attr(x, "warbleR.version"))) else
+      cat("created by warbleR < 1.1.21")
+  }
 
 ##############################################################################################################
 
@@ -523,7 +538,12 @@ print.selection_table <- function(x, ...) {
   
   if (nrow(x) > 6) cat(paste0("... and ", nrow(x) - 6, " more rows \n"))  
   
-  cat("and a data frame (check.results) generated by checkres() (as attribute)")
+  cat("and a data frame (check.results) generated by check_sels() (as attribute) \n")
+  
+  # print warbleR version
+  if (!is.null(attr(x, "warbleR.version")))
+   cat(paste0("created by warbleR ", attr(x, "warbleR.version"))) else
+     cat("created by warbleR < 1.1.21")
 }
 
 ##############################################################################################################
@@ -601,6 +621,8 @@ rbind.selection_table <- function(..., deparse.level = 1) {
   
   if (any(paste(X$sound.files, X$selec) %in% paste(Y$sound.files, Y$selec))) stop("Some sound files/selec are found in both selection tables")
   
+  
+  
   cl.nms <- intersect(names(X), names(Y))
   
   W <- rbind(as.data.frame(X[ , cl.nms, drop = FALSE]), as.data.frame(Y[ , cl.nms, drop = FALSE]), make.row.names = TRUE,
@@ -660,6 +682,11 @@ rbind.extended_selection_table <- function(..., deparse.level = 1) {
   
   if (any(paste(X$sound.files, X$selec) %in% paste(Y$sound.files, Y$selec))) stop("Some sound files/selec are found in both extended selection tables")
   
+  waves.X <- names(attr(X, "wave.objects"))
+  waves.Y <- names(attr(Y, "wave.objects"))
+  
+  if (any(waves.X %in% waves.Y)) cat("Some wave object names are found in both extended selection tables, they are assumed to refer to the same wave object and only one copy will be kept (use rename_waves_est() to change sound file/wave objetc names if needed)")
+  
   cl.nms <- intersect(names(X), names(Y))
   
   W <- rbind(as.data.frame(X[ , cl.nms, drop = FALSE]), as.data.frame(Y[ , cl.nms, drop = FALSE]), make.row.names = TRUE)
@@ -673,7 +700,10 @@ rbind.extended_selection_table <- function(..., deparse.level = 1) {
   attr(W, "by.song") <- attr(X, "by.song")
   
   class(W) <- class(X)
-  
+ 
+  # remove duplicated  if any
+  attr(W, "wave.objects") <- attr(W, "wave.objects")[duplicated(names(attr(W, "wave.objects")))]
+   
   return(W)
 }
 
